==> haskell-patience-0.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 patience
version:              0.3
visibility:           public
id:                   patience-0.3-I62H27wz80L2IOqnO6Lhfl
key:                  patience-0.3-I62H27wz80L2IOqnO6Lhfl
license:              BSD-3-Clause
maintainer:           chessai <chessai1996@gmail.com>
author:
    Keegan McAllister <mcallister.keegan@gmail.com>
    chessai <chessai1996@gmail.com>

homepage:             https://github.com/chessai/patience
synopsis:             Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.

    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.

category:             Algorithms, Text
abi:                  4acf0a13ce4d8ee94fa59a0b2aef2526
exposed:              True
exposed-modules:      Patience Patience.Map
import-dirs:          /usr/lib/ghc-8.8.3/site-local/patience-0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/patience-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/patience-0.3
hs-libraries:         HSpatience-0.3-I62H27wz80L2IOqnO6Lhfl
depends:              base-4.13.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html:         /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-patience-0.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 patience
version:              0.3
visibility:           public
id:                   patience-0.3-KVrZMIAPBnY7TSUWyYBEAT
key:                  patience-0.3-KVrZMIAPBnY7TSUWyYBEAT
license:              BSD-3-Clause
maintainer:           chessai <chessai1996@gmail.com>
author:
    Keegan McAllister <mcallister.keegan@gmail.com>
    chessai <chessai1996@gmail.com>

homepage:             https://github.com/chessai/patience
synopsis:             Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.

    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.

category:             Algorithms, Text
abi:                  2ff0f3c4f75edaf845787a8dde5ebc67
exposed:              True
exposed-modules:      Patience Patience.Map
import-dirs:          /usr/lib/ghc-8.10.1/site-local/patience-0.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/patience-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/patience-0.3
hs-libraries:         HSpatience-0.3-KVrZMIAPBnY7TSUWyYBEAT
depends:              base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html:         /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
